@@ -4,10 +4,6 @@
 /*
  * Nessus system includes 
  */
-#if defined(LINUX)
-/* Bug 1388: to get memmem() prototype */
-#define _GNU_SOURCE
-#endif
 #include <config.h>
 
 #ifndef HAVE_MEMCPY
