@@ -54,20 +54,8 @@
  * Level 2202
  * Only signed scripts can write 'Secret/' entries in the KB
  * New function: open_sock_to_kdc()
- *
- * Level 2203
- * New function send_capture()
- * Fixed shared sockets
- *
- * Level 2204
- * Arrays of arrays 
- *
- * Level 2205
- * Fixed a bug in copying arrays of arrays
- *
- *
  */
-#define NASL_LEVEL 2205
+#define NASL_LEVEL 2202
 
 
 int execute_nasl_script(struct arglist *, const char *, const char *, int);
@@ -84,10 +72,4 @@ void  nasl_server_recompile(char*, char *);
 #define NASL_COMMAND_LINE		   (1 << 4)
 #define NASL_LINT			   (1 << 5)
 
-
-#define NASL_ERR_NOERR		0
-#define NASL_ERR_ETIMEDOUT 	1
-#define NASL_ERR_ECONNRESET	2
-#define NASL_ERR_EUNREACH	3
-#define NASL_ERR_EUNKNOWN	99
 #endif
