@@ -70,7 +70,19 @@ cell2bool(lex_ctxt* lexic, tree_cell* c)
       if (c->size == 0)
 	return 0;
       if(c->x.str_val[0] == '0' && c->size == 1)
+	{
+	  /* 
+	   * This gives the same semantics as Perl ("0" is false), 
+	   * but I do not agree with it. 
+	   * This piece of code is here from the begining of NASL2; it 
+	   * probably fixed some compatibility issue with old 
+	   * quick & dirty scripts. 
+	   * I added this warning to check if we can switch to a
+	   * simpler behaviour (empty string = false, not empty = true)
+	   */
+	  nasl_perror(lexic, "cell2boll: string '0' is FALSE\n");
 	  return 0;
+	}
      return 1;
 
     case REF_ARRAY:
@@ -1819,7 +1831,7 @@ execute_nasl_script(struct arglist * script_infos, const char* name, const char
 
      tc.type = CONST_DATA;
      p = strrchr(name, '/');
-     if (p == NULL) p = name; else p ++;
+     if (p == NULL) p = (char*)name; else p ++;
      tc.x.str_val = p;
      tc.size = strlen(p);
      add_named_var_to_ctxt(lexic, "SCRIPT_NAME", &tc);
