@@ -106,7 +106,9 @@ static init_func libfuncs[] = {
   "join_multicast_group", nasl_join_multicast_group, 1, { NULL },
   "leave_multicast_group", nasl_leave_multicast_group, 1, { NULL },
   "get_source_port", nasl_get_source_port, 1, { NULL }, /* DOC! */
-  
+  "get_sock_errno", nasl_get_sock_errno, 1, { NULL }, /* DOC! */
+  "errno_conn_reset", nasl_errno_conn_reset, 1, { NULL }, /* DOC! */
+
   "cgibin",		cgibin,		  0, { NULL },
   "is_cgi_installed",   nasl_is_cgi_installed, 1, {"item", "port", NULL },
   "http_open_socket",   http_open_socket, 1, { NULL },
@@ -175,6 +177,9 @@ static init_func libfuncs[] = {
   "localtime",	nasl_localtime, 1, { "utc" },
   "mktime",	nasl_mktime, 0, { "hour", "isdst", "mday", "min", "mon", "sec", "year" },
 
+
+  "open_sock_kdc", nasl_open_sock_kdc, 0, { NULL },
+
   "telnet_init",	nasl_telnet_init, 1, { NULL },
   "ftp_log_in",	nasl_ftp_log_in, 0, {"pass", "socket", "user", NULL },
   "ftp_get_pasv_port", nasl_ftp_get_pasv_address, 0, { "socket", NULL }, 
@@ -279,13 +284,6 @@ static init_func libfuncs[] = {
   "rsa_sign", nasl_rsa_sign, 0, { "d", "data", "e", "n", NULL },
   "dsa_do_sign", nasl_dsa_do_sign, 0, { "data", "g", "p", "priv", "pub", "q", NULL },  
 #endif  
-  "NTLMv1_HASH",  nasl_ntlmv1_hash, 0, {"cryptkey", "passhash", NULL },
-  "NTLMv2_HASH",  nasl_ntlmv2_hash, 0, {"cryptkey", "length", "passhash", NULL }, 
-#ifdef HAVE_OPENSSL_MD4_H
-  "nt_owf_gen", nasl_nt_owf_gen, 1, { NULL },
-#endif
-  "lm_owf_gen", nasl_lm_owf_gen, 1, { NULL },
-  "ntv2_owf_gen", nasl_ntv2_owf_gen, 0, {"domain", "login", "owf", NULL },
 
   "pread", nasl_pread, 0, { "argv", "cd", "cmd", "nice", NULL },
   "find_in_path", nasl_find_in_path, 1, { NULL },
@@ -294,6 +292,14 @@ static init_func libfuncs[] = {
   "unlink", nasl_unlink, 1, { NULL },
   "get_tmp_dir", nasl_get_tmp_dir, 0, { NULL },
 
+
+  "file_stat", nasl_file_stat, 1, { NULL },
+  "file_open", nasl_file_open, 0, { "mode", "name", NULL },
+  "file_close", nasl_file_close, 1, { NULL },
+  "file_read", nasl_file_read, 0, { "fp", "length", NULL },
+  "file_write", nasl_file_write, 0, { "data", "fp", NULL },
+  "file_seek", nasl_file_seek, 0, { "fp", "offset", NULL }, 
+
   "shared_socket_register", nasl_shared_socket_register, 0, { "name", "socket", NULL},
   "shared_socket_acquire", nasl_shared_socket_acquire, 1, { NULL },
   "shared_socket_release", nasl_shared_socket_release, 1, { NULL },
@@ -321,6 +327,8 @@ static struct {
   "ENCAPS_SSLv2",  NESSUS_ENCAPS_SSLv2,
   "ENCAPS_SSLv3",  NESSUS_ENCAPS_SSLv3,
   "ENCAPS_TLSv1",  NESSUS_ENCAPS_TLSv1,
+  "ENCAPS_TLSv10",  NESSUS_ENCAPS_TLSv10,
+  "ENCAPS_TLSv11",  NESSUS_ENCAPS_TLSv11,
 
   "NASL_LEVEL",	NASL_LEVEL,
 
@@ -350,6 +358,49 @@ static struct {
 
   "MSG_OOB", MSG_OOB,
 
+#ifdef EINTR
+  "EINTR", EINTR,
+#endif
+#ifdef EBADF
+  "EBADF", EBADF,
+#endif
+#ifdef EAGAIN
+  "EAGAIN", EAGAIN,
+#endif
+#ifdef ENOMEM
+  "ENOMEM", ENOMEM,
+#endif
+#ifdef EACCES
+  "EACCES", EACCES,
+#endif
+#ifdef EFAULT
+  "EFAULT", EFAULT,
+#endif
+#ifdef EINVAL
+  "EINVAL", EINVAL,
+#endif
+#ifdef ENFILE
+  "ENFILE", ENFILE,
+#endif
+#ifdef EMFILE
+  "EMFILE", EMFILE,
+#endif
+#ifdef ESPIPE
+  "ESPIPE", ESPIPE,
+#endif
+#ifdef EPIPE
+  "EPIPE", EPIPE,
+#endif
+#ifdef EDOM
+  "EDOM", EDOM, 
+#endif
+#ifdef ERANGE
+  "ERANGE", ERANGE,
+#endif
+#ifdef ECONNRESET
+  "ECONNRESET", ECONNRESET,
+#endif
+
   NULL, 0, 
 };
 /* See also in exec.c:
