@@ -773,6 +773,14 @@ tree_cell * set_kb_item(lex_ctxt * lexic)
   return FAKE_CELL;
  }
  
+ if (! lexic->authenticated && 
+     strncmp(name, SECRET_KB_PREFIX, sizeof(SECRET_KB_PREFIX) - 1) == 0)
+ {
+  nasl_perror(lexic, "Only signed scripts can set a Secret/ KB entry\n");
+  return FAKE_CELL;
+ }
+
+
  if(type == VAR2_INT)
  {
   int value = get_int_local_var_by_name(lexic, "value", -1);
