@@ -25,7 +25,6 @@
 #include "nasl_var.h"
 #include "nasl_lex_ctxt.h"
 #include "exec.h"
-#include "nasl_socket.h"
 
 #include "nasl_debug.h"
 #include "capture_packet.h"
@@ -456,7 +455,7 @@ tree_cell*	forge_tcp_packet(lex_ctxt* lexic)
 
 tree_cell * get_tcp_element(lex_ctxt * lexic)
 {
- u_char * packet = (u_char*)get_str_local_var_by_name(lexic, "tcp");
+ u_char * packet = get_str_local_var_by_name(lexic, "tcp");
  struct ip * ip;
  int	ipsz;
  struct tcphdr * tcp;
@@ -615,7 +614,7 @@ tree_cell * dump_tcp_packet(lex_ctxt * lexic)
 {
  int i = 0;
  u_char * pkt;
- while((pkt = (u_char*)get_str_var_by_num(lexic, i++)) != NULL)
+ while((pkt = (char*)get_str_var_by_num(lexic, i++)) != NULL)
  {
     int a=0;
     struct ip * ip = (struct ip*)pkt;
@@ -743,7 +742,7 @@ tree_cell * forge_udp_packet(lex_ctxt * lexic)
   
   retc = alloc_tree_cell(0, NULL);
   retc->type = CONST_DATA;
-  retc->x.str_val = (char*)pkt;
+  retc->x.str_val = pkt;
   retc->size = 8 + ip->ip_hl * 4 + data_len;
   return retc;
  }
@@ -928,7 +927,7 @@ tree_cell * dump_udp_packet(lex_ctxt * lexic)
 {
  int i = 0;
  u_char * pkt;
- while((pkt = (u_char*)get_str_var_by_num(lexic, i++)) != NULL)
+ while((pkt = get_str_var_by_num(lexic, i++)) != NULL)
  {
    struct udphdr * udp = (struct udphdr*)(pkt+sizeof(struct ip));
    int j;
@@ -1010,7 +1009,7 @@ tree_cell*	forge_icmp_packet(lex_ctxt* lexic)
       
       retc = alloc_tree_cell(0, NULL);
       retc->type = CONST_DATA;
-      retc->x.str_val = (char*)pkt;
+      retc->x.str_val = pkt;
       retc->size = ip_sz + len + 8;
     }
   else
@@ -1139,7 +1138,7 @@ tree_cell * forge_igmp_packet(lex_ctxt * lexic)
   }
    retc = alloc_tree_cell(0, NULL);
    retc->type = CONST_DATA;
-   retc->x.str_val = (char*)pkt;
+   retc->x.str_val = pkt;
    retc->size = ip->ip_hl * 4 + sizeof(struct igmp) + len;
    return retc;
   }
@@ -1165,16 +1164,20 @@ tree_cell * nasl_tcp_ping(lex_ctxt * lexic)
  int i = 0;
  int bpf;
  char filter[255];
- u_char * pk = NULL;
+ struct ip * pk = NULL;
  tree_cell * retc;
  int opt = 1;
- struct timeval tv;
- int len;
 #define rnd_tcp_port() (rand() % 65535 + 1024)
+
+ 
+ 
  int sports[]= { 0,     0,   0,  0,  0, 1023, 0,  0,    0,    0,  0,   0,    0,    0,    0,  0,   0,   0,    0,    0, 53,   0,    0,    20,   0,  25,   0,    0, 0};
  int ports[] = { 139, 135, 445, 80, 22, 515, 23, 21, 6000, 1025, 25, 111, 1028, 9100, 1029, 79, 497, 548, 5000, 1917, 53, 161, 9001, 65535, 443, 113, 993, 8080, 0};
+ 
+ 
+ 
+ 
  int num_ports = 0;
- int custom_port = 0;
  
  
  if( dst == NULL ) 
@@ -1204,10 +1207,7 @@ tree_cell * nasl_tcp_ping(lex_ctxt * lexic)
 
  port = get_int_local_var_by_name(lexic, "port", -1);
  if(port == -1)
-	{
 	 port = plug_get_host_open_port(script_infos);
-	 custom_port ++;
-	}
  
  if(islocalhost(dst) > 0 )src.s_addr = dst->s_addr;
   else 
@@ -1264,10 +1264,8 @@ tree_cell * nasl_tcp_ping(lex_ctxt * lexic)
  soca.sin_family = AF_INET;
  soca.sin_addr = ip->ip_dst;
  sendto(soc, (const void*)ip, 40, 0, (struct sockaddr *)&soca, sizeof(soca));
- tv.tv_sec = 0;
- tv.tv_usec = 100000;
- if(bpf >= 0 && (pk = bpf_next_tv(bpf, &len, &tv)))flag++;	
- if ( flag == 0 && custom_port != 0 ) port = plug_get_host_open_port(script_infos);
+ if(bpf >= 0 && (pk = capture_next_packet(bpf, 0, NULL)))flag++;	
+ i++;
   }
  }
 
@@ -1309,8 +1307,6 @@ tree_cell*	nasl_send_packet(lex_ctxt* lexic)
  if(setsockopt(soc, IPPROTO_IP, IP_HDRINCL, (char*)&i, sizeof(i))<0)
 	perror("setsockopt ");
 #endif
-
-
  
   while ((ip = get_str_var_by_num(lexic, vi)) != NULL)
     {
@@ -1324,9 +1320,9 @@ tree_cell*	nasl_send_packet(lex_ctxt* lexic)
       }
       
       sip = (struct ip *)ip;
+     
       if( use_pcap != 0 && bpf < 0)
 	bpf = init_capture_device(sip->ip_dst, sip->ip_src, filter);
-     
 
       bzero(&sockaddr, sizeof(struct sockaddr_in));
       sockaddr.sin_family = AF_INET;
@@ -1377,7 +1373,7 @@ tree_cell*	nasl_send_packet(lex_ctxt* lexic)
 	    {
   	      retc = alloc_tree_cell(0, NULL);
   	      retc->type = CONST_DATA;
-	      retc->x.str_val = (char*)answer;
+	      retc->x.str_val = answer;
 	      retc->size = answer_sz;
               break;
 	    }
@@ -1476,92 +1472,3 @@ tree_cell * nasl_pcap_next(lex_ctxt* lexic)
  
  return retc;
 }
-
-tree_cell * nasl_send_capture(lex_ctxt* lexic)
-{
- char * interface = get_str_local_var_by_name(lexic, "interface");
- int bpf = -1;
- static char errbuf[PCAP_ERRBUF_SIZE];
- int is_ip = 0;
- struct ip * ret = NULL;
- char *filter = get_str_local_var_by_name(lexic, "pcap_filter");
- int timeout = get_int_local_var_by_name(lexic, "timeout", 5);
- tree_cell * retc;
- int sz;
- struct in_addr * dst = plug_get_host_ip(lexic->script_infos);
-
- if(interface == NULL )
- 	{
-	struct in_addr src;
-	bzero(&src, sizeof(src));
-    	interface = routethrough(dst, &src);
-	if( interface == NULL )interface = pcap_lookupdev(errbuf);
-	}
-	
- if(interface != NULL)
-  bpf = bpf_open_live(interface, filter);
- 
- 
- if(bpf < 0)
-  {
-   nasl_perror(lexic, "pcap_next: Could not get a bpf\n");
-   return NULL;
-  }
- else
- {
-  int len;
-  int dl_len = get_datalink_size(bpf_datalink(bpf));
-  char * packet;
-  struct timeval then, now;
-  
-  
-  retc = nasl_send(lexic); 
-  efree(&retc);
-
-  gettimeofday(&then, NULL);
-  for(;;)
-  {
-  packet = (char*)bpf_next(bpf, &len);
-  
-  if(packet != NULL)
-  	break;
-	
-  if(timeout != 0)
-   {
-    gettimeofday(&now, NULL);
-    if(now.tv_sec - then.tv_sec >= timeout)break;
-   }
-  }
-
-  if(packet)
-  {
-   struct ip * ip;   
-   ip = (struct ip*)(packet + dl_len);
-   sz = UNFIX(ip->ip_len);
-   ret = emalloc(sz);
-  
-   is_ip = (ip->ip_v == 4);
-   if(is_ip)
-   {
-	
-	 bcopy(ip, ret, sz);
-   }
-   else {
-	   sz = len - dl_len;
-	   bcopy(ip, ret, sz);
-   }
-  }
-  else {
-    bpf_close(bpf);
-    return NULL;
-  }
- }
- bpf_close(bpf);
- retc = alloc_tree_cell(0, NULL);
- 
- retc->type = CONST_DATA;
- retc->x.str_val = (char*)ret;
- retc->size = sz;
- 
- return retc;
-}
