@@ -193,7 +193,7 @@ restart:
 	 return NULL;
 
 tryagain :
- if ( current_sport < 128 ) return NULL;
+ if ( current_sport < 128 && sport < 0 ) return NULL;
  e =  set_socket_source_addr(sock, sport > 0 ? sport : current_sport--);
  
  /*
@@ -241,6 +241,13 @@ tryagain :
   e = select(sock + 1, NULL, &rd, NULL, to > 0 ? &tv:NULL);
   } while ( e < 0 && errno == EINTR );
 
+  if (e == 0)			/* timeout */
+    {
+      /* Should we set /tmp/ConnectTimeout/TCP/<port> ? */
+      close(sock);
+      return NULL;
+    }
+
  block_socket(sock);
  opt_sz = sizeof(opt);
 
@@ -764,3 +771,58 @@ nasl_get_source_port(lex_ctxt* lexic)
   retc->x.i_val = ntohs(ia.sin_port);
   return retc;  
 }
+
+
+tree_cell*
+nasl_get_sock_errno(lex_ctxt* lexic)
+{
+  int		s, err;
+  tree_cell	*retc;
+
+  s = get_int_var_by_num(lexic, 0, -1);
+  if (s < 0)
+    {
+      nasl_perror(lexic, "get_sock_errno: missing socket parameter\n");
+      return NULL;
+    }
+  err = get_and_clear_stream_socket_errno(s);
+  if (err == -1)
+    return NULL;
+
+  retc = alloc_typed_cell(CONST_INT);
+  retc->x.i_val = err;
+  return retc;  
+}
+
+tree_cell*
+nasl_errno_conn_reset(lex_ctxt* lexic)
+{
+  tree_cell	*retc = NULL;
+  int		e, flag = 0, test = 0;
+
+  e = get_int_var_by_num(lexic, 0, -1);
+  if (e < 0)
+    {
+      nasl_perror(lexic, "errno_conn_reset: missing error parameter\n");
+      return NULL;
+    }
+  
+#ifdef ECONNRESET
+  if (e == ECONNRESET)
+    flag = 1;
+  test ++;
+#endif
+  /* More tests should be added for other Unix flavours */
+
+  if (test == 0)
+    {
+      nasl_perror(lexic, "errno_conn_reset is not implemented on this operating system\n");
+      return NULL;
+    }
+
+  retc = alloc_typed_cell(CONST_INT);
+  retc->x.i_val = flag;
+  return retc;
+}
+
+
