@@ -363,7 +363,7 @@ tree_cell* nasl_hexstr(lex_ctxt * lexic)
 tree_cell* nasl_ord(lex_ctxt* lexic)
 {
   tree_cell	*retc;
-  unsigned char	*val = (unsigned char*)get_str_var_by_num(lexic, 0);
+  unsigned char	*val = get_str_var_by_num(lexic, 0);
 
  
   if (val == NULL)
@@ -682,7 +682,7 @@ tree_cell * nasl_egrep(lex_ctxt * lexic)
   else 
   	copt = 0;
 	
-  rets = emalloc(max_size + 2);
+  rets = emalloc(max_size + 1);
   string = estrdup(string);
   
   
@@ -789,10 +789,7 @@ nasl_eregmatch(lex_ctxt* lexic)
     }
   
   if(nasl_regexec(&re, string, (size_t)NS, subs, 0) != 0)
-   {
-    nasl_regfree(&re);
     return NULL;
-   }
       
   retc = alloc_tree_cell(0, NULL);
   retc->type = DYN_ARRAY;
@@ -803,7 +800,7 @@ nasl_eregmatch(lex_ctxt* lexic)
       {
 	v.var_type = VAR2_DATA;
 	v.v.v_str.s_siz = subs[i].rm_eo - subs[i].rm_so;
-	v.v.v_str.s_val = (unsigned char*)string + subs[i].rm_so;
+	v.v.v_str.s_val = string + subs[i].rm_so;
 	(void) add_var_to_list(a, i, &v);
       }
 
@@ -830,7 +827,7 @@ tree_cell* nasl_substr(lex_ctxt* lexic)
 #define MAX_INT (~(1 << (sizeof(int) * 8 - 1)))
 #endif
   i2 = get_int_var_by_num(lexic, 2, MAX_INT);
-  if (i2 >= sz1) i2 = sz1-1;
+  if (i2 > sz1) i2 = sz1-1;
 
   if (s1 == NULL || i1 < 0)
     {
@@ -879,7 +876,7 @@ tree_cell* nasl_insstr(lex_ctxt* lexic)
       return NULL;
     }
 
-  if (i1 >= sz1)
+  if (i1 > sz1)
     {
       nasl_perror(lexic, "insstr: cannot insert string2 after end of string1\n");
       return NULL;
@@ -924,12 +921,12 @@ nasl_match(lex_ctxt* lexic)
   if (pattern == NULL)
     {
       nasl_perror(lexic, "nasl_match: parameter 'pattern' missing\n");
-      return NULL;
+      pattern = "";
     }
   if (string == NULL)
     {
       nasl_perror(lexic, "nasl_match: parameter 'string' missing\n");
-      return NULL;
+      string = "";
     }
 
   retc = alloc_tree_cell(0, NULL);
@@ -964,16 +961,7 @@ nasl_split(lex_ctxt* lexic)
 
   sep = get_str_local_var_by_name(lexic, "sep");
   if (sep != NULL)
-    {
     sep_len = get_var_size_by_name(lexic, "sep");
-    if ( sep_len <= 0 ) sep_len = strlen(sep);
-    if ( sep_len <= 0 ) 
-	{
-      	   nasl_perror(lexic, "split: invalid 'seplen' parameter\n");
-	   return NULL;
-	}
-    }
-
   keep = get_int_local_var_by_name(lexic, "keep", 1);
 
   retc = alloc_tree_cell(0, NULL);
@@ -988,10 +976,10 @@ nasl_split(lex_ctxt* lexic)
       i = 0; j = 0;
       for(;;)
 	{
-	  if ((p = (char*)nasl_memmem(str + i, len - i, sep, sep_len)) == NULL)
+	  if ((p = (char*)memmem(str + i, len - i, sep, sep_len)) == NULL)
 	    {
 	      v.v.v_str.s_siz = len - i;
-	      v.v.v_str.s_val = (unsigned char*)str + i;
+	      v.v.v_str.s_val = str + i;
 	      (void) add_var_to_list(a, j ++, &v);
 	      return retc;
 	    }
@@ -1001,7 +989,7 @@ nasl_split(lex_ctxt* lexic)
 		v.v.v_str.s_siz = (p - (str + i)) + sep_len;
 	      else
 		v.v.v_str.s_siz = p - (str + i); 
-	      v.v.v_str.s_val = (unsigned char*)str + i;
+	      v.v.v_str.s_val = str + i;
 	      (void) add_var_to_list(a, j ++, &v);
 	      i = (p - str) + sep_len;
 	      if (i >= len)
@@ -1020,7 +1008,7 @@ nasl_split(lex_ctxt* lexic)
 	    v.v.v_str.s_siz = i - i0 + 1;
 	  else
 	    v.v.v_str.s_siz = i - i0 - 1;
-	  v.v.v_str.s_val = (unsigned char*)str + i0;
+	  v.v.v_str.s_val = str + i0;
 	  i0 = i + 1;
 	  (void) add_var_to_list(a, j ++, &v);
 	}
@@ -1030,7 +1018,7 @@ nasl_split(lex_ctxt* lexic)
 	    v.v.v_str.s_siz = i - i0 + 1;
 	  else
 	    v.v.v_str.s_siz = i - i0;
-	  v.v.v_str.s_val = (unsigned char*)str + i0;
+	  v.v.v_str.s_val = str + i0;
 	  i0 = i + 1;
 	  (void) add_var_to_list(a, j ++, &v);
 	}
@@ -1039,7 +1027,7 @@ nasl_split(lex_ctxt* lexic)
   if (i > i0)
     {
       v.v.v_str.s_siz = i - i0;
-      v.v.v_str.s_val = (unsigned char*)str + i0;
+      v.v.v_str.s_val = str + i0;
       (void) add_var_to_list(a, j ++, &v);
     }
   return retc;
@@ -1162,7 +1150,7 @@ tree_cell* nasl_strstr(lex_ctxt * lexic)
  if(sz_b > sz_a)
   return NULL;
  
- c = (char*)nasl_memmem(a, sz_a, b, sz_b);
+ c = (char*)memmem(a, sz_a, b, sz_b);
  if(c == NULL)
   return FAKE_CELL;
  
@@ -1209,7 +1197,7 @@ nasl_stridx(lex_ctxt * lexic)
   if ((sz_a == start) || (sz_b > sz_a + start))
     return retc;
 
-  c = (char*)nasl_memmem(a + start, sz_a - start, b, sz_b);
+  c = (char*)memmem(a + start, sz_a - start, b, sz_b);
   if(c != NULL)
     retc->x.i_val = c - a;
   return retc;
@@ -1258,9 +1246,9 @@ nasl_str_replace(lex_ctxt * lexic)
   s = emalloc(1);
   sz2 = 0;
   n = 0;
-  for (i1 = i2 = 0; i1 <= sz_a - sz_b; )
+  for (i1 = i2 = 0; i1 < sz_a - sz_b; )
     {
-      c = (char*)nasl_memmem(a + i1, sz_a - i1, b, sz_b);
+      c = (char*)memmem(a + i1, sz_a - i1, b, sz_b);
       if(c == NULL)
 	break;
       l = (c - a) - i1; 
