@@ -119,7 +119,7 @@ get_var_by_name(nasl_array* a, const char* s)
 
 
 /* This function climbs up in the context list */
-static named_nasl_var*
+named_nasl_var*
 get_var_ref_by_name(lex_ctxt* ctxt, const char* name, int climb)
 {
   named_nasl_var	*v, *prev;
@@ -626,6 +626,9 @@ affect_to_anon_var(anon_nasl_var* v1, tree_cell* rval)
   void		*p;
 
 
+  if ( v1 == NULL || v1 == FAKE_CELL )
+	return NULL;
+
   t1 = v1->var_type;
 
   if (rval == NULL || rval == FAKE_CELL)
@@ -906,7 +909,7 @@ add_numbered_var_to_ctxt(lex_ctxt* lexic, int num, tree_cell* val)
     }
   else
     {
-      a->num_elt = erealloc(a->num_elt, (num+1) * sizeof(anon_nasl_var));
+      a->num_elt = erealloc(a->num_elt, (num+1) * sizeof(anon_nasl_var*));
       bzero(a->num_elt + a->max_idx, sizeof(anon_nasl_var*) * (num+1 - a->max_idx));
       a->max_idx = num + 1;
     }
